@@ -51,6 +51,7 @@ enum
 };
 
 #define MOUSE_SCHEMA "org.mate.peripherals-mouse"
+#define INTERFACE_SCHEMA "org.mate.interface"
 #define DOUBLE_CLICK_KEY "double-click"
 
 #define TOUCHPAD_SCHEMA "org.mate.peripherals-touchpad"
@@ -61,6 +62,7 @@ enum
 static gint double_click_state = DOUBLE_CLICK_TEST_OFF;
 
 static GSettings *mouse_settings = NULL;
+static GSettings *interface_settings = NULL;
 static GSettings *touchpad_settings = NULL;
 
 /* Double Click handling */
@@ -175,6 +177,7 @@ orientation_radio_button_toggled (GtkToggleButton *togglebutton,
 static void
 synaptics_check_capabilities (GtkBuilder *dialog)
 {
+	GdkDisplay *display;
 	int numdevices, i;
 	XDeviceInfo *devicelist;
 	Atom realtype, prop;
@@ -182,23 +185,24 @@ synaptics_check_capabilities (GtkBuilder *dialog)
 	unsigned long nitems, bytes_after;
 	unsigned char *data;
 
-	prop = XInternAtom (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), "Synaptics Capabilities", True);
+	display = gdk_display_get_default ();
+	prop = XInternAtom (GDK_DISPLAY_XDISPLAY(display), "Synaptics Capabilities", True);
 	if (!prop)
 		return;
 
-	devicelist = XListInputDevices (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), &numdevices);
+	devicelist = XListInputDevices (GDK_DISPLAY_XDISPLAY(display), &numdevices);
 	for (i = 0; i < numdevices; i++) {
 		if (devicelist[i].use != IsXExtensionPointer)
 			continue;
 
-		gdk_error_trap_push ();
-		XDevice *device = XOpenDevice (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()),
+		gdk_x11_display_error_trap_push (display);
+		XDevice *device = XOpenDevice (GDK_DISPLAY_XDISPLAY(display),
 					       devicelist[i].id);
-		if (gdk_error_trap_pop ())
+		if (gdk_x11_display_error_trap_pop (display))
 			continue;
 
-		gdk_error_trap_push ();
-		if ((XGetDeviceProperty (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device, prop, 0, 2, False,
+		gdk_x11_display_error_trap_push (display);
+		if ((XGetDeviceProperty (GDK_DISPLAY_XDISPLAY(display), device, prop, 0, 2, False,
 					 XA_INTEGER, &realtype, &realformat, &nitems,
 					 &bytes_after, &data) == Success) && (realtype != None)) {
 			/* Property data is booleans for has_left, has_middle,
@@ -211,9 +215,9 @@ synaptics_check_capabilities (GtkBuilder *dialog)
 			XFree (data);
 		}
 
-		gdk_error_trap_pop_ignored ();
+		gdk_x11_display_error_trap_pop_ignored (display);
 
-		XCloseDevice (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), device);
+		XCloseDevice (GDK_DISPLAY_XDISPLAY(display), device);
 	}
 	XFreeDeviceList (devicelist);
 }
@@ -267,6 +271,15 @@ setup_dialog (GtkBuilder *dialog)
 	g_settings_bind (mouse_settings, "locate-pointer", WID ("locate_pointer_toggle"),
 		"active", G_SETTINGS_BIND_DEFAULT);
 
+	/* Middle Button Emulation */
+	g_settings_bind (mouse_settings, "middle-button-enabled", WID ("middle_button_emulation_toggle"),
+		"active", G_SETTINGS_BIND_DEFAULT);
+
+	/* Middle Button Paste */
+	g_settings_bind (interface_settings, "gtk-enable-primary-paste", WID ("middle_button_paste_toggle"),
+		"active", G_SETTINGS_BIND_DEFAULT);
+
+
 	/* Double-click time */
 	g_settings_bind (mouse_settings, DOUBLE_CLICK_KEY,
 		gtk_range_get_adjustment (GTK_RANGE (WID ("delay_scale"))), "value",
@@ -426,6 +439,7 @@ main (int argc, char **argv)
 	activate_settings_daemon ();
 
 	mouse_settings = g_settings_new (MOUSE_SCHEMA);
+	interface_settings = g_settings_new (INTERFACE_SCHEMA);
 	touchpad_settings = g_settings_new (TOUCHPAD_SCHEMA);
 
 	dialog = create_dialog ();
@@ -465,6 +479,7 @@ main (int argc, char **argv)
 	}
 
 	g_object_unref (mouse_settings);
+	g_object_unref (interface_settings);
 	g_object_unref (touchpad_settings);
 
 	return 0;
